#[repr(C)]pub struct DeviceProgramKeyResponse {
pub slot: u8,
}Fields
slot: u8Trait Implementations
Sourceimpl Clone for DeviceProgramKeyResponse
impl Clone for DeviceProgramKeyResponse
Sourcefn clone(&self) -> DeviceProgramKeyResponse
fn clone(&self) -> DeviceProgramKeyResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeviceProgramKeyResponse
impl Debug for DeviceProgramKeyResponse
Sourceimpl<'a, ___E> Encode<DeviceProgramKeyResponse, ___E> for &'a DeviceProgramKeyResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DeviceProgramKeyResponse, ___E> for &'a DeviceProgramKeyResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceProgramKeyResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceProgramKeyResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DeviceProgramKeyResponse, ___E> for DeviceProgramKeyResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DeviceProgramKeyResponse, ___E> for DeviceProgramKeyResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceProgramKeyResponse, DeviceProgramKeyResponse>
const COPY_OPTIMIZATION: CopyOptimization<DeviceProgramKeyResponse, DeviceProgramKeyResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceProgramKeyResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceProgramKeyResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, DeviceProgramKeyResponse>, ___E> for &'a DeviceProgramKeyResponse
impl<'a, ___E> EncodeOption<Box<'static, DeviceProgramKeyResponse>, ___E> for &'a DeviceProgramKeyResponse
Sourcefn encode_option(
this: Option<&'a DeviceProgramKeyResponse>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceProgramKeyResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a DeviceProgramKeyResponse>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceProgramKeyResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, DeviceProgramKeyResponse>, ___E> for DeviceProgramKeyResponse
impl<___E> EncodeOption<Box<'static, DeviceProgramKeyResponse>, ___E> for DeviceProgramKeyResponse
Sourcefn encode_option(
this: Option<DeviceProgramKeyResponse>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceProgramKeyResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<DeviceProgramKeyResponse>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceProgramKeyResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<DeviceProgramKeyResponse> for DeviceProgramKeyResponse
impl FromWire<DeviceProgramKeyResponse> for DeviceProgramKeyResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceProgramKeyResponse, DeviceProgramKeyResponse>
const COPY_OPTIMIZATION: CopyOptimization<DeviceProgramKeyResponse, DeviceProgramKeyResponse>
Sourcefn from_wire(wire: DeviceProgramKeyResponse) -> DeviceProgramKeyResponse
fn from_wire(wire: DeviceProgramKeyResponse) -> DeviceProgramKeyResponse
Converts the given owned value to this type.
Sourceimpl FromWireRef<DeviceProgramKeyResponse> for DeviceProgramKeyResponse
impl FromWireRef<DeviceProgramKeyResponse> for DeviceProgramKeyResponse
Sourcefn from_wire_ref(wire: &DeviceProgramKeyResponse) -> DeviceProgramKeyResponse
fn from_wire_ref(wire: &DeviceProgramKeyResponse) -> DeviceProgramKeyResponse
Converts the given reference to this type.
Sourceimpl Hash for DeviceProgramKeyResponse
impl Hash for DeviceProgramKeyResponse
Sourceimpl Ord for DeviceProgramKeyResponse
impl Ord for DeviceProgramKeyResponse
Sourcefn cmp(&self, other: &DeviceProgramKeyResponse) -> Ordering
fn cmp(&self, other: &DeviceProgramKeyResponse) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DeviceProgramKeyResponse
impl PartialEq for DeviceProgramKeyResponse
Sourceimpl PartialOrd for DeviceProgramKeyResponse
impl PartialOrd for DeviceProgramKeyResponse
impl Copy for DeviceProgramKeyResponse
impl Eq for DeviceProgramKeyResponse
impl StructuralPartialEq for DeviceProgramKeyResponse