pub trait DeviceLocalServerHandler<___T: Transport = Channel> {
// Required methods
fn program_key(
&mut self,
request: Request<ProgramKey, ___T>,
responder: Responder<ProgramKey, ___T>,
) -> impl Future<Output = ()>;
fn derive_raw_secret(
&mut self,
request: Request<DeriveRawSecret, ___T>,
responder: Responder<DeriveRawSecret, ___T>,
) -> impl Future<Output = ()>;
}Expand description
A server handler for the Device protocol.
See Device for more details.
Required Methods
Sourcefn program_key(
&mut self,
request: Request<ProgramKey, ___T>,
responder: Responder<ProgramKey, ___T>,
) -> impl Future<Output = ()>
fn program_key( &mut self, request: Request<ProgramKey, ___T>, responder: Responder<ProgramKey, ___T>, ) -> impl Future<Output = ()>
Programs the ephemerally wrapped wrapped_key into the inline encryption hardware in the
next available slot. All slots programmed via the connection this method is called on
will be evicted once the connection is dropped. It is not possible to evict individual keys
(not for any technical reasons; a need for this has not yet arisen). wrapped_key must be
a key wrapped by the inline encryption hardware (in the same session/boot) via a separate
mechanism to this protocol.
Returns
- ZX_ERR_NO_RESOURCES if there are no available key slots.
- ZX_ERR_INVALID_ARGS if
wrapped_keyis not the expected size or if thewrapped_keyfails authentication (e.g. wrapped_key is from a previous boot). - ZX_ERR_TIMED_OUT if the operation times out.
- ZX_ERR_INTERNAL if the operation failed for any other reason.
Sourcefn derive_raw_secret(
&mut self,
request: Request<DeriveRawSecret, ___T>,
responder: Responder<DeriveRawSecret, ___T>,
) -> impl Future<Output = ()>
fn derive_raw_secret( &mut self, request: Request<DeriveRawSecret, ___T>, responder: Responder<DeriveRawSecret, ___T>, ) -> impl Future<Output = ()>
Derives a raw software secret from the ephemerally wrapped wrapped_key. wrapped_key
must be a key wrapped by the inline encryption hardware (in the same session/boot) via a
separate mechanism to this protocol. The returned secret can be used for non-inline
cryptographic operations e.g. it can be used for encrypting filesystem metadata not covered
by inline encryption.
Returns
- ZX_ERR_INVALID_ARGS if
wrapped_keyis not the expected size or if thewrapped_keyfails authentication (e.g. wrapped_key is from a previous boot). - ZX_ERR_TIMED_OUT if the operation times out.
- ZX_ERR_INTERNAL if the operation failed for any other reason.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.